Hello community,

here is the log from the commit of package rubygem-libyui-rake for 
openSUSE:Factory checked in at 2018-06-20 15:29:16
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/rubygem-libyui-rake (Old)
 and      /work/SRC/openSUSE:Factory/.rubygem-libyui-rake.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "rubygem-libyui-rake"

Wed Jun 20 15:29:16 2018 rev:4 rq:617472 version:0.1.10

Changes:
--------
--- /work/SRC/openSUSE:Factory/rubygem-libyui-rake/rubygem-libyui-rake.changes  
2017-06-16 10:54:41.428283699 +0200
+++ 
/work/SRC/openSUSE:Factory/.rubygem-libyui-rake.new/rubygem-libyui-rake.changes 
    2018-06-20 15:30:40.179572381 +0200
@@ -1,0 +2,20 @@
+Fri Jun 15 13:12:04 UTC 2018 - [email protected]
+
+- switch sle_latest to SLE15 SP1 and switch SLE15 GA to
+  maintenance mode (bsc#1044312)
+- 0.1.10
+
+-------------------------------------------------------------------
+Thu Apr 19 11:16:14 UTC 2018 - [email protected]
+
+- add SLE12 SP4 as target and switch sle_latest to nil for now
+  until IBS create project for SLE15 SP1. (bsc#1044312)
+- 0.1.9
+
+-------------------------------------------------------------------
+Mon Feb  5 13:43:37 UTC 2018 - [email protected]
+
+- Allow 4 digits in version numbers (bsc#1074596)
+- 0.1.8
+
+-------------------------------------------------------------------

Old:
----
  libyui-rake-0.1.7.gem

New:
----
  libyui-rake-0.1.10.gem

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ rubygem-libyui-rake.spec ++++++
--- /var/tmp/diff_new_pack.9NKOpb/_old  2018-06-20 15:30:41.259533199 +0200
+++ /var/tmp/diff_new_pack.9NKOpb/_new  2018-06-20 15:30:41.291532038 +0200
@@ -1,7 +1,7 @@
 #
 # spec file for package rubygem-libyui-rake
 #
-# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -17,7 +17,7 @@
 
 
 Name:           rubygem-libyui-rake
-Version:        0.1.7
+Version:        0.1.10
 Release:        0
 %define mod_name libyui-rake
 %define mod_full_name %{mod_name}-%{version}
@@ -28,7 +28,7 @@
 Url:            http://github.org/openSUSE/libyui-rake
 Source:         http://rubygems.org/gems/%{mod_full_name}.gem
 Summary:        Rake tasks providing basic work-flow for libyui development
-License:        LGPL-2.1
+License:        LGPL-2.1-only
 Group:          Development/Languages/Ruby
 
 %description

++++++ libyui-rake-0.1.7.gem -> libyui-rake-0.1.10.gem ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/VERSION new/VERSION
--- old/VERSION 2017-06-15 11:10:26.000000000 +0200
+++ new/VERSION 2018-04-23 15:14:58.000000000 +0200
@@ -1 +1 @@
-0.1.7
+0.1.10
Binary files old/checksums.yaml.gz and new/checksums.yaml.gz differ
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/data/targets.yml new/data/targets.yml
--- old/data/targets.yml        2017-06-15 11:10:26.000000000 +0200
+++ new/data/targets.yml        2018-04-23 15:14:58.000000000 +0200
@@ -34,16 +34,21 @@
   obs_project: "Devel:YaST:SLE-12-SP3"
   obs_sr_project: "SUSE:SLE-12-SP3:Update"
   obs_target: "SLE_12_SP3"
+:sle12sp4:
+  obs_api: "https://api.suse.de/";
+  obs_project: "Devel:YaST:SLE-12-SP4"
+  obs_sr_project: "SUSE:SLE-12-SP4:GA"
+  obs_target: "SLE_12_SP4"
 :sle15:
   obs_api: "https://api.suse.de/";
-  obs_project: "Devel:YaST:Head"
-  obs_sr_project: "SUSE:SLE-15:GA"
+  obs_project: "Devel:YaST:SLE-15"
+  obs_sr_project: "SUSE:SLE-15:Update"
   obs_target: "SUSE_SLE-15_GA"
 :sle_latest:
   obs_api: "https://api.suse.de/";
   obs_project: "Devel:YaST:Head"
-  obs_sr_project: "SUSE:SLE-15:GA"
-  obs_target: "SUSE_SLE-15_GA"
+  obs_sr_project: "SUSE:SLE-15-SP1:GA"
+  obs_target: "SUSE_SLE-15-SP1_GA"
 :factory:
   obs_project: "devel:libraries:libyui"
   obs_sr_project: "openSUSE:Factory"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/metadata new/metadata
--- old/metadata        2017-06-15 12:43:15.000000000 +0200
+++ new/metadata        2018-06-18 11:50:29.000000000 +0200
@@ -1,14 +1,14 @@
 --- !ruby/object:Gem::Specification
 name: libyui-rake
 version: !ruby/object:Gem::Version
-  version: 0.1.7
+  version: 0.1.10
 platform: ruby
 authors:
 - YaST team
 autorequire: 
 bindir: bin
 cert_chain: []
-date: 2017-06-15 00:00:00.000000000 Z
+date: 2018-06-18 00:00:00.000000000 Z
 dependencies:
 - !ruby/object:Gem::Dependency
   name: rake
@@ -68,7 +68,7 @@
 - lib/libyui/tasks.rb
 - lib/tasks/test.rake
 - lib/tasks/version.rake
-homepage: http://github.org/openSUSE/libyui-rake
+homepage: https://github.com/openSUSE/libyui-rake
 licenses:
 - LGPL-2.1
 metadata: {}
@@ -88,7 +88,7 @@
       version: '0'
 requirements: []
 rubyforge_project: 
-rubygems_version: 2.4.5.2
+rubygems_version: 2.7.3
 signing_key: 
 specification_version: 4
 summary: Rake tasks providing basic work-flow for libyui development


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lib/libyui/tasks.rb new/lib/libyui/tasks.rb
--- old/lib/libyui/tasks.rb     2017-06-15 11:10:26.000000000 +0200
+++ new/lib/libyui/tasks.rb     2018-04-23 15:14:58.000000000 +0200
@@ -55,19 +55,21 @@
       def cmake_value(s, key)
         e_key = Regexp.escape(key)
         m = /SET\s*\(\s*#{e_key}\s+"([^"]*)"\s*\)/.match(s)
-        m[1]
+        m ? m[1] : nil
       end
 
       # Returns the CMake version from version file
       #
       # @param  [String] Version file (VERSION_CMAKE by default)
-      # @return [String] like "1.2.3"
+      # @return [String] like "1.2.3" or "1.2.3.4"
       # @see VERSION_CMAKE
       def cmake_version(file = nil)
         f = File.read(file || VERSION_CMAKE)
         [cmake_value(f, "VERSION_MAJOR"),
          cmake_value(f, "VERSION_MINOR"),
-         cmake_value(f, "VERSION_PATCH")].join(".")
+         cmake_value(f, "VERSION_PATCH"),
+         cmake_value(f, "VERSION_TWEAK")].compact.join(".")
       end
     end
   end
@@ -55,19 +55,21 @@
       end
 
-      # Returns the CMake version from version file
+      # Returns the CMake version from the version file.
+      # VERSION_TWEAK is optional.
       #
       # @param  [String] Version file (VERSION_CMAKE by default)